import "./Alert.css";
import { forwardRef, isNil, isNilOrEmpty, mergeProps, useChainedEventCallback, useSlots } from "../../shared";
import { Button, ButtonGroup } from "../../button";
import { useMemo } from "react";
import { Dialog, useDialogTriggerContext } from "../../dialog";
import { Header } from "../../placeholders";
import { InfoIcon, WarningIcon } from "../../icons";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerAlert({
  variant = "confirmation",
  primaryButtonLabel,
  primaryButtonDisabled,
  secondaryButtonLabel,
  secondaryButtonDisabled,
  cancelButtonLabel,
  autoFocusButton,
  onPrimaryButtonClick,
  onSecondaryButtonClick,
  onCancelButtonClick,
  zIndex = 1,
  children,
  forwardedRef,
  ...rest
}) {
  const {
    close
  } = useDialogTriggerContext();
  const {
    heading,
    content
  } = useSlots(children, useMemo(() => ({
    _: {
      required: ["heading", "content"]
    },
    heading: null,
    content: null
  }), []));
  const handlePrimaryButtonClick = useChainedEventCallback(onPrimaryButtonClick, event => {
    if (!isNil(close)) {
      close(event);
    }
  });
  const handleSecondaryButtonClick = useChainedEventCallback(onSecondaryButtonClick, event => {
    if (!isNil(close)) {
      close(event);
    }
  });
  const handleCancelButtonClick = useChainedEventCallback(onCancelButtonClick, event => {
    if (!isNil(close)) {
      close(event);
    }
  });

  const warningIconMarkup = variant === "warning" && /*#__PURE__*/_jsx(Header, {
    children: /*#__PURE__*/_jsx(WarningIcon, {
      size: "lg",
      className: "o-ui-alert-warning-icon"
    })
  });

  const negativeIconMarkup = variant === "negative" && /*#__PURE__*/_jsx(Header, {
    children: /*#__PURE__*/_jsx(InfoIcon, {
      size: "lg",
      className: "o-ui-alert-negative-icon"
    })
  });

  const primaryButtonMarkup = /*#__PURE__*/_jsx(Button, {
    color: variant === "destructive" ? "danger" : undefined,
    disabled: primaryButtonDisabled,
    onClick: handlePrimaryButtonClick,
    autoFocus: isNil(autoFocusButton) || autoFocusButton === "primary",
    children: primaryButtonLabel
  });

  const secondaryButtonMarkup = !isNilOrEmpty(secondaryButtonLabel) && /*#__PURE__*/_jsx(Button, {
    variant: "outline",
    disabled: secondaryButtonDisabled,
    onClick: handleSecondaryButtonClick,
    autoFocus: autoFocusButton === "secondary",
    children: secondaryButtonLabel
  });

  const cancelButtonMarkup = !isNilOrEmpty(cancelButtonLabel) && /*#__PURE__*/_jsx(Button, {
    variant: "outline",
    onClick: handleCancelButtonClick,
    autoFocus: autoFocusButton === "cancel",
    children: cancelButtonLabel
  });

  const buttonsMarkup = isNil(secondaryButtonMarkup) && isNil(cancelButtonMarkup) ? primaryButtonMarkup : /*#__PURE__*/_jsxs(ButtonGroup, {
    children: [cancelButtonMarkup, secondaryButtonMarkup, primaryButtonMarkup]
  });
  return /*#__PURE__*/_jsxs(Dialog, { ...mergeProps(rest, {
      role: "alertdialog",
      size: "sm",
      dismissable: false,
      zIndex,
      ref: forwardedRef
    }),
    children: [heading, warningIconMarkup, negativeIconMarkup, content, buttonsMarkup]
  });
}
export const Alert = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerAlert, { ...props,
  forwardedRef: ref
}));
Alert.displayName = "Alert";