import "./Dialog.css";
import { AriaLabelingProps, DomProps, InteractionStatesProps } from "../../shared";
import { ComponentProps, ElementType, ForwardedRef, ReactNode } from "react";
export interface InnerDialogProps extends DomProps, AriaLabelingProps, InteractionStatesProps {
    /**
     * The dialog role.
     */
    role?: "dialog" | "alertdialog";
    /**
     * A dialog can vary in size.
     */
    size?: "sm" | "md" | "lg" | "fullscreen";
    /**
     * Whether or not the dialog should close on outside interactions.
     */
    dismissable?: boolean;
    /**
     * The z-index of the dialog.
     */
    zIndex?: number;
    /**
     * Additional props to render on the wrapper element.
     */
    wrapperProps?: Record<string, any>;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerDialog({ id, role, size, dismissable, focus, zIndex, "aria-label": ariaLabel, "aria-labelledby": ariaLabelledBy, wrapperProps, as, children, forwardedRef, ...rest }: InnerDialogProps): JSX.Element;
export declare const Dialog: import("../../shared").OrbitComponent<HTMLElement, InnerDialogProps>;
export declare type DialogProps = ComponentProps<typeof Dialog>;
