import { Box } from "../../box";
import { useMemo } from "react";
import { cssModule, forwardRef, isNil, mergeProps, useEventCallback, useSlots } from "../../shared";
import { ItemKeyProp } from "./Menu";
import { Text } from "../../typography";
import { TooltipTrigger } from "../../tooltip";
import { useMenuContext } from "./MenuContext";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
const RoleBySelectionMode = {
  none: "menuitem",
  single: "menuitemradio",
  multiple: "menuitemcheckbox"
};
export function InnerMenuItem({
  item: {
    key,
    tooltip
  },
  id,
  disabled,
  active,
  focus,
  hover,
  as = "li",
  children,
  forwardedRef,
  ...rest
}) {
  var _text$props, _description$props;

  const {
    selectedKeys,
    selectionMode,
    onSelect
  } = useMenuContext();
  const handleClick = useEventCallback(event => {
    if (!disabled) {
      onSelect(event, key);
    }
  });
  const handleMouseEnter = useEventCallback(event => {
    event.target.focus();
  });
  const {
    icon,
    avatar,
    text,
    description,
    "end-icon": endIcon
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    icon: (_iconElement, slotElements) => {
      return {
        className: "o-ui-menu-item-start-icon",
        size: isNil(slotElements.description) ? "sm" : "lg"
      };
    },
    avatar: (_avatarElement, slotElements) => {
      return {
        className: "o-ui-menu-item-option-avatar",
        size: isNil(slotElements.description) ? "2xs" : "md"
      };
    },
    text: {
      id: `${id}-label`,
      className: "o-ui-menu-item-label"
    },
    description: {
      id: `${id}-description`,
      className: "o-ui-menu-item-description",
      size: "md"
    },
    "end-icon": {
      size: "sm",
      className: "o-ui-menu-item-end-icon"
    }
  }), [id]));
  const labelId = text === null || text === void 0 ? void 0 : (_text$props = text.props) === null || _text$props === void 0 ? void 0 : _text$props.id;
  const descriptionId = description === null || description === void 0 ? void 0 : (_description$props = description.props) === null || _description$props === void 0 ? void 0 : _description$props.id;
  const role = RoleBySelectionMode[selectionMode];

  const itemMarkup = /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      id,
      onClick: !disabled ? handleClick : undefined,
      onMouseEnter: handleMouseEnter,
      className: cssModule("o-ui-menu-item", description && "has-description", active && "active", focus && "focus", hover && "hover"),
      role,
      // Disabled menu item are still focusable.
      tabIndex: -1,
      [ItemKeyProp]: key,
      "aria-checked": role !== RoleBySelectionMode.none ? !disabled && selectedKeys.includes(key) : undefined,
      "aria-disabled": disabled,
      "aria-labelledby": labelId,
      "aria-describedby": description && descriptionId,
      as,
      ref: forwardedRef
    }),
    children: [icon, avatar, text, description, endIcon]
  });

  if (!isNil(tooltip)) {
    const {
      props: tooltipProps,
      content: tooltipContent
    } = tooltip;
    return /*#__PURE__*/_jsxs(TooltipTrigger, { ...mergeProps(tooltipProps, {
        position: "left"
      }),
      children: [itemMarkup, tooltipContent]
    });
  }

  return itemMarkup;
}
export const MenuItem = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerMenuItem, { ...props,
  forwardedRef: ref
}));
MenuItem.displayName = "MenuItem";