import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { GroupProps } from "../../group";
export interface InnerTileGroupProps {
    /**
     * The value of the tile group.
     */
    value?: string[] | null;
    /**
     * The initial value of `value`.
     */
    defaultValue?: string[];
    /**
     * The type of selection that is allowed.
     */
    selectionMode?: "none" | "single" | "multiple";
    /**
     * The number of tiles per row.
     */
    rowSize?: number;
    /**
     * Called when any of the children is checked or unchecked..
     * @param {SyntheticEvent} event - React's original event.
     * @param {string[]} value - The new value.
     * @returns {void}
     */
    onChange?: (event: SyntheticEvent, value: string[]) => void;
    /**
     * The orientation of the group tiles.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * Whether or not the first tile of the group should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not the tiles are disabled.
     */
    disabled?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export interface UnselectableGroupProps extends GroupProps {
    autoFocus?: boolean | number;
}
export declare function InnerTileGroup({ value, defaultValue, selectionMode, rowSize, onChange, orientation, disabled, children, forwardedRef, ...rest }: InnerTileGroupProps): JSX.Element;
export declare const TileGroup: import("../../shared").OrbitComponent<HTMLElement, InnerTileGroupProps>;
export declare type TileGroupProps = ComponentProps<typeof TileGroup>;
