import { CheckboxGroup } from "../../checkbox";
import { Children, forwardRef as reactForwardRef } from "react";
import { Group } from "../../group";
import { RadioGroup } from "../../radio";
import { arrayify, augmentElement, forwardRef, isNil, isNumber, mergeProps, useAutoFocusChild, useEventCallback, useFocusManager, useFocusScope, useMergedRefs } from "../../shared";
import { jsx as _jsx } from "react/jsx-runtime";
const UnselectableGroup = /*#__PURE__*/reactForwardRef(({
  autoFocus,
  children,
  ...rest
}, ref) => {
  const [focusScope, setFocusRef] = useFocusScope();
  const groupRef = useMergedRefs(setFocusRef, ref);
  const focusManager = useFocusManager(focusScope);
  useAutoFocusChild(focusManager, {
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  return /*#__PURE__*/_jsx(Group, { ...rest,
    ref: groupRef,
    children: children
  });
});
const GroupType = {
  "none": UnselectableGroup,
  "single": RadioGroup,
  "multiple": CheckboxGroup
};

function denormalizeValue(value, selectionMode) {
  if (!isNil(value) && selectionMode === "single") {
    return value[0];
  }

  return value;
}

export function InnerTileGroup({
  value,
  defaultValue,
  selectionMode = "none",
  rowSize = 1,
  onChange,
  orientation,
  disabled,
  children,
  forwardedRef,
  ...rest
}) {
  const As = GroupType[selectionMode];
  const handleChange = useEventCallback((event, newValue) => {
    if (!isNil(onChange)) {
      onChange(event, arrayify(newValue));
    }
  });
  return /*#__PURE__*/_jsx(As, { ...mergeProps(rest, {
      orientation: "horizontal",
      // If you change the gap, also update the tile size gap (currently 16px) below.
      gap: 4,
      wrap: true,
      fluid: true,
      ref: forwardedRef
    }, selectionMode === "none" ? {} : {
      value: denormalizeValue(value, selectionMode),
      defaultValue: denormalizeValue(defaultValue, selectionMode),
      onChange: handleChange,
      disabled
    }),
    children: Children.toArray(children).filter(x => x).map(x => {
      return augmentElement(x, {
        orientation,
        disabled: selectionMode === "none" ? disabled : undefined,
        style: {
          width: `calc((100% - ${(rowSize - 1) * 16}px) / ${rowSize})`
        }
      });
    })
  });
}
export const TileGroup = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTileGroup, { ...props,
  forwardedRef: ref
}));
TileGroup.displayName = "TileGroup";