import { ComponentProps, ElementType, ForwardedRef, ReactNode } from "react";
import { InteractionStatesProps } from "../../shared";
export interface InnerTileLinkProps extends InteractionStatesProps {
    /**
     * The URL that the link points to. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    href?: string;
    /**
     * Where to display the linked URL, as the name for a browsing context (a tab, window, or iframe). See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    target?: string;
    /**
     * The relationship of the linked URL as space-separated link types. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    rel?: string;
    /**
     * The orientation of the tile.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * Whether or not this is an external link.
     */
    external?: boolean;
    /**
     * Whether or not the tile should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not the tile is disabled.
     */
    disabled?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerTileLink({ orientation, disabled, active, focus, hover, children, forwardedRef, ...rest }: InnerTileLinkProps): JSX.Element;
export declare const TileLink: import("../../shared").OrbitComponent<HTMLElement, InnerTileLinkProps>;
export declare type TileLinkProps = ComponentProps<typeof TileLink>;
